<?php

namespace Survey\Formms\Http\Controllers;

use App\Http\Controllers\ResourceController as BaseController;
use Form;
use Survey\Formms\Http\Requests\FormmsRequest;
use Survey\Formms\Interfaces\FormmsRepositoryInterface;
use Survey\Formms\Models\Formms;

/**
 * Resource controller class for formms.
 */
class FormmsResourceController extends BaseController
{

    /**
     * Initialize formms resource controller.
     *
     * @param type FormmsRepositoryInterface $formms
     *
     * @return null
     */
    public function __construct(FormmsRepositoryInterface $formms)
    {
        parent::__construct();
        $this->repository = $formms;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Survey\Formms\Repositories\Criteria\FormmsResourceCriteria::class);
    }

    /**
     * Display a list of formms.
     *
     * @return Response
     */
    public function index(FormmsRequest $request)
    {
        $view = $this->response->theme->listView();

        if ($this->response->typeIs('json')) {
            $function = camel_case('get-' . $view);
            return $this->repository
                ->setPresenter(\Survey\Formms\Repositories\Presenter\FormmsPresenter::class)
                ->$function();
        }

        $formms = $this->repository->paginate();

        return $this->response->setMetaTitle(trans('formms::formms.names'))
            ->view('formms::formms.index', true)
            ->data(compact('formms', 'view'))
            ->output();
    }

    /**
     * Display formms.
     *
     * @param Request $request
     * @param Model   $formms
     *
     * @return Response
     */
    public function show(FormmsRequest $request, Formms $formms)
    {

        if ($formms->exists) {
            $view = 'formms::formms.show';
        } else {
            $view = 'formms::formms.new';
        }

        return $this->response->setMetaTitle(trans('app.view') . ' ' . trans('formms::formms.name'))
            ->data(compact('formms'))
            ->view($view, true)
            ->output();
    }

    /**
     * Show the form for creating a new formms.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(FormmsRequest $request)
    {

        $formms = $this->repository->newInstance([]);
        return $this->response->setMetaTitle(trans('app.new') . ' ' . trans('formms::formms.name')) 
            ->view('formms::formms.create', true) 
            ->data(compact('formms'))
            ->output();
    }

    /**
     * Create new formms.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(FormmsRequest $request)
    {
        try {
            $attributes              = $request->all();
            $attributes['user_id']   = user_id();
            $attributes['user_type'] = user_type();
            $formms                 = $this->repository->create($attributes);

            return $this->response->message(trans('messages.success.created', ['Module' => trans('formms::formms.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('formms/formms/' . $formms->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('/formms/formms'))
                ->redirect();
        }

    }

    /**
     * Show formms for editing.
     *
     * @param Request $request
     * @param Model   $formms
     *
     * @return Response
     */
    public function edit(FormmsRequest $request, Formms $formms)
    {
        return $this->response->setMetaTitle(trans('app.edit') . ' ' . trans('formms::formms.name'))
            ->view('formms::formms.edit', true)
            ->data(compact('formms'))
            ->output();
    }

    /**
     * Update the formms.
     *
     * @param Request $request
     * @param Model   $formms
     *
     * @return Response
     */
    public function update(FormmsRequest $request, Formms $formms)
    {
        try {
            $attributes = $request->all();

            $formms->update($attributes);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('formms::formms.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('formms/formms/' . $formms->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('formms/formms/' . $formms->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove the formms.
     *
     * @param Model   $formms
     *
     * @return Response
     */
    public function destroy(FormmsRequest $request, Formms $formms)
    {
        try {

            $formms->delete();
            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('formms::formms.name')]))
                ->code(202)
                ->status('success')
                ->url(guard_url('formms/formms/0'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('formms/formms/' . $formms->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove multiple formms.
     *
     * @param Model   $formms
     *
     * @return Response
     */
    public function delete(FormmsRequest $request, $type)
    {
        try {
            $ids = hashids_decode($request->input('ids'));

            if ($type == 'purge') {
                $this->repository->purge($ids);
            } else {
                $this->repository->delete($ids);
            }

            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('formms::formms.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('formms/formms'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/formms/formms'))
                ->redirect();
        }

    }

    /**
     * Restore deleted formms.
     *
     * @param Model   $formms
     *
     * @return Response
     */
    public function restore(FormmsRequest $request)
    {
        try {
            $ids = hashids_decode($request->input('ids'));
            $this->repository->restore($ids);

            return $this->response->message(trans('messages.success.restore', ['Module' => trans('formms::formms.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('/formms/formms'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/formms/formms/'))
                ->redirect();
        }

    }

}
